/********************************************************
 *  ██████╗  ██████╗████████╗██╗
 * ██╔════╝ ██╔════╝╚══██╔══╝██║
 * ██║  ███╗██║        ██║   ██║
 * ██║   ██║██║        ██║   ██║
 * ╚██████╔╝╚██████╗   ██║   ███████╗
 *  ╚═════╝  ╚═════╝   ╚═╝   ╚══════╝
 * Geophysical Computational Tools & Library (GCTL)
 *
 * Copyright (c) 2023  Yi Zhang (yizhang-geo@zju.edu.cn)
 *
 * GCTL is distributed under a dual licensing scheme. You can redistribute 
 * it and/or modify it under the terms of the GNU Lesser General Public 
 * License as published by the Free Software Foundation, either version 2 
 * of the License, or (at your option) any later version. You should have 
 * received a copy of the GNU Lesser General Public License along with this 
 * program. If not, see <http://www.gnu.org/licenses/>.
 * 
 * If the terms and conditions of the LGPL v.2. would prevent you from using 
 * the GCTL, please consider the option to obtain a commercial license for a 
 * fee. These licenses are offered by the GCTL's original author. As a rule, 
 * licenses are provided "as-is", unlimited in time for a one time fee. Please 
 * send corresponding requests to: yizhang-geo@zju.edu.cn. Please do not forget 
 * to include some description of your company and the realm of its activities. 
 * Also add information on how to contact you by electronic and paper mail.
 ******************************************************/

#ifndef GCTL_DSVIEWER_H
#define GCTL_DSVIEWER_H

#include "../../lib/gctl_config.h"
#include "../../lib/io.h"

using namespace gctl;

// Function pointer for commands
typedef void (*cmd_func_ptr)(const std::vector<std::string> &cmd_units);

struct cmd_pair
{
    std::string name;
    cmd_func_ptr func_p;
    std::string brief;
};

void quit(const std::vector<std::string> &cmd_units);
void info(const std::vector<std::string> &cmd_units);
void load_file(const std::vector<std::string> &cmd_units);
void save_file(const std::vector<std::string> &cmd_units);
void statistic(const std::vector<std::string> &cmd_units);

#define CMD_NUM 6
const cmd_pair commands[CMD_NUM] = {
    {"quit", quit, "Quit the program."},
    {"info", info, "Show the table information."},
    {"open", load_file, "Open a dsv/csv file."},
    {"save", save_file, "Save the table to a file."},
    {"stats", statistic, "Calculate statistics of the selected columns."},
    {"null", nullptr, "null"}
};

#endif // GCTL_DSVIEWER_H